# qt5-gesture-extensions

    qt5-gesture-extensions are some dynamic libraries, provide some gesture extensions 

## Depends

    debhelper-compat (= 12),
    qtbase5-dev-tools,
    qttools5-dev-tools,
    qtbase5-dev.
    qt5-qmake

## Build&Install

```bash
    mkdir build

    cd build

    qmake ..

    make

    sudo make install # install
```

## Include

If you want to run-time loading, please call registerWidget, is a `c-style` interface

or if you want to load at compile time, just `#include <qt5-gesture-extensions/qt5-gesture-extensions.h>`

## Interface

    c-style interface:

```C++
    extern "C" void registerWidget(QWidget* widget, QObject* parent);
    extern "C" void unregisterWidget(QWidget* widget, QObject* parent);
```

    c++ interface:
```C++
namespace UkuiGestureExtension {
class QT5GESTUREEXTENSIONS_EXPORT GestureExtensionManager : public QObject
{
public:
    ~GestureExtensionManager();
    /*!
     * \brief registerWidget
     * \details register the widget to all extension
    */
    void registerWidget(QWidget* widget);
    /*!
     * \brief unregisterWidget
     * \details unregister the widget to all extension
    */
    void unregisterWidget(QWidget* widget);

    static GestureExtensionManager* getInstance(QObject* parent = nullptr);
};

} // namespace
```

you can use 
```C++
    bool QObject::setProperty(const char *name, const QVariant &value);
```
to ban some extension for your widget, such as:
```C++
    setProperty("notUseSlideGesture", true); // ban Slide List View Extension for your widget
```
## Extensions List

    * SlideListViewGesture
        make your QAbstractItemView can scroll when you touch
        property:notUseSlideGesture

## TODO

    * Load extension from extension dir
